@@ -590,7 +590,7 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         annotations = assertions.Annotations.from_stack(stack)
     '''
 
-    @jsii.member(jsii_name="fromStack") # type: ignore[misc]
+    @jsii.member(jsii_name="fromStack")
     @builtins.classmethod
     def from_stack(cls, stack: aws_cdk.core.Stack) -> "Annotations":
         '''Base your assertions on the messages returned by a synthesized CDK ``Stack``.
@@ -738,19 +738,19 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
     def __init__(self) -> None:
         jsii.create(self.__class__, self, [])
 
-    @jsii.member(jsii_name="absent") # type: ignore[misc]
+    @jsii.member(jsii_name="absent")
     @builtins.classmethod
     def absent(cls) -> "Matcher":
         '''Use this matcher in the place of a field's value, if the field must not be present.'''
         return typing.cast("Matcher", jsii.sinvoke(cls, "absent", []))
 
-    @jsii.member(jsii_name="anyValue") # type: ignore[misc]
+    @jsii.member(jsii_name="anyValue")
     @builtins.classmethod
     def any_value(cls) -> "Matcher":
         '''Matches any non-null value at the target.'''
         return typing.cast("Matcher", jsii.sinvoke(cls, "anyValue", []))
 
-    @jsii.member(jsii_name="arrayEquals") # type: ignore[misc]
+    @jsii.member(jsii_name="arrayEquals")
     @builtins.classmethod
     def array_equals(cls, pattern: typing.Sequence[typing.Any]) -> "Matcher":
         '''Matches the specified pattern with the array found in the same relative path of the target.
@@ -764,7 +764,7 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "arrayEquals", [pattern]))
 
-    @jsii.member(jsii_name="arrayWith") # type: ignore[misc]
+    @jsii.member(jsii_name="arrayWith")
     @builtins.classmethod
     def array_with(cls, pattern: typing.Sequence[typing.Any]) -> "Matcher":
         '''Matches the specified pattern with the array found in the same relative path of the target.
@@ -778,7 +778,7 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "arrayWith", [pattern]))
 
-    @jsii.member(jsii_name="exact") # type: ignore[misc]
+    @jsii.member(jsii_name="exact")
     @builtins.classmethod
     def exact(cls, pattern: typing.Any) -> "Matcher":
         '''Deep exact matching of the specified pattern to the target.
@@ -790,7 +790,7 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "exact", [pattern]))
 
-    @jsii.member(jsii_name="not") # type: ignore[misc]
+    @jsii.member(jsii_name="not")
     @builtins.classmethod
     def not_(cls, pattern: typing.Any) -> "Matcher":
         '''Matches any target which does NOT follow the specified pattern.
@@ -802,7 +802,7 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "not", [pattern]))
 
-    @jsii.member(jsii_name="objectEquals") # type: ignore[misc]
+    @jsii.member(jsii_name="objectEquals")
     @builtins.classmethod
     def object_equals(
         cls,
@@ -819,7 +819,7 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "objectEquals", [pattern]))
 
-    @jsii.member(jsii_name="objectLike") # type: ignore[misc]
+    @jsii.member(jsii_name="objectLike")
     @builtins.classmethod
     def object_like(
         cls,
@@ -836,7 +836,7 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "objectLike", [pattern]))
 
-    @jsii.member(jsii_name="serializedJson") # type: ignore[misc]
+    @jsii.member(jsii_name="serializedJson")
     @builtins.classmethod
     def serialized_json(cls, pattern: typing.Any) -> "Matcher":
         '''Matches any string-encoded JSON and applies the specified pattern after parsing it.
@@ -848,7 +848,7 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "serializedJson", [pattern]))
 
-    @jsii.member(jsii_name="stringLikeRegexp") # type: ignore[misc]
+    @jsii.member(jsii_name="stringLikeRegexp")
     @builtins.classmethod
     def string_like_regexp(cls, pattern: builtins.str) -> "Matcher":
         '''Matches targets according to a regular expression.
@@ -1127,13 +1127,13 @@ class MatchResult(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.MatchR
         '''Get the list of failures as human readable strings.'''
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "toHumanStrings", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="failCount")
     def fail_count(self) -> jsii.Number:
         '''The number of failures.'''
         return typing.cast(jsii.Number, jsii.get(self, "failCount"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="target")
     def target(self) -> typing.Any:
         '''The target for which this result was generated.'''
@@ -1176,7 +1176,7 @@ class Matcher(
     def __init__(self) -> None:
         jsii.create(self.__class__, self, [])
 
-    @jsii.member(jsii_name="isMatcher") # type: ignore[misc]
+    @jsii.member(jsii_name="isMatcher")
     @builtins.classmethod
     def is_matcher(cls, x: typing.Any) -> builtins.bool:
         '''Check whether the provided object is a subtype of the ``IMatcher``.
@@ -1188,7 +1188,7 @@ class Matcher(
             check_type(argname="argument x", value=x, expected_type=type_hints["x"])
         return typing.cast(builtins.bool, jsii.sinvoke(cls, "isMatcher", [x]))
 
-    @jsii.member(jsii_name="test") # type: ignore[misc]
+    @jsii.member(jsii_name="test")
     @abc.abstractmethod
     def test(self, actual: typing.Any) -> MatchResult:
         '''Test whether a target matches the provided pattern.
@@ -1202,7 +1202,7 @@ class Matcher(
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     @abc.abstractmethod
     def name(self) -> builtins.str:
@@ -1230,7 +1230,7 @@ class _MatcherProxy(Matcher):
             check_type(argname="argument actual", value=actual, expected_type=type_hints["actual"])
         return typing.cast(MatchResult, jsii.invoke(self, "test", [actual]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''A name for the matcher.
@@ -1261,7 +1261,7 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         template = Template.from_stack(stack)
     '''
 
-    @jsii.member(jsii_name="fromJSON") # type: ignore[misc]
+    @jsii.member(jsii_name="fromJSON")
     @builtins.classmethod
     def from_json(
         cls,
@@ -1276,7 +1276,7 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
             check_type(argname="argument template", value=template, expected_type=type_hints["template"])
         return typing.cast("Template", jsii.sinvoke(cls, "fromJSON", [template]))
 
-    @jsii.member(jsii_name="fromStack") # type: ignore[misc]
+    @jsii.member(jsii_name="fromStack")
     @builtins.classmethod
     def from_stack(cls, stack: aws_cdk.core.Stack) -> "Template":
         '''Base your assertions on the CloudFormation template synthesized by a CDK ``Stack``.
@@ -1288,7 +1288,7 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast("Template", jsii.sinvoke(cls, "fromStack", [stack]))
 
-    @jsii.member(jsii_name="fromString") # type: ignore[misc]
+    @jsii.member(jsii_name="fromString")
     @builtins.classmethod
     def from_string(cls, template: builtins.str) -> "Template":
         '''Base your assertions from an existing CloudFormation template formatted as a JSON string.
@@ -1625,7 +1625,7 @@ class Capture(
             check_type(argname="argument actual", value=actual, expected_type=type_hints["actual"])
         return typing.cast(MatchResult, jsii.invoke(self, "test", [actual]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''A name for the matcher.
